@@ -1,3 +1,4 @@
+
 from datetime import datetime, timedelta
 from sqlite3 import Timestamp
 from dateutil.parser import parse
@@ -7,8 +8,11 @@ import os
 from os import SEEK_END
 import matplotlib.pyplot as plt
 import matplotlib.dates as mdates
+import matplotlib.ticker as ticker
 import re
 
+
+
 def is_file_in_time_range(file_path, delta_mins=10, date_selected=datetime.now()):
     """检测文件是否符合期望的时间要求
 
@@ -99,6 +103,33 @@ def check_line_in_a_file(f, delta_mins, date_selected=datetime.now()):
     return True
 
 
+def find_datetime_in_line(line):
+    '''从一行文本中找到时间字符串'''
+    # datetime like: 2022-11-07T08:48:24.269000+0800
+    # if match return it, else return None
+    try:
+        return re.findall(r"\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{6}\+\d{4}", line)[0]
+    except Exception:
+        return None
+
+
+def find_voltage_in_line(line):
+    '''从一行文本中找到电压值'''
+    # voltage like "v 26.95" ofr "v 27"
+    try:
+        return float(re.findall(r"v\s(\d+\.\d+$|\d+$)", line)[0])
+    except Exception:
+        return None
+
+
+def find_torque_in_line(line):
+    '''从一行文本中找到扭矩值'''
+    try:
+        return int(re.findall(r"t\s(-?\d+)", line)[0])
+    except Exception:
+        return None
+
+
 def read_data_lines(data_f, date_selected, time_range):
     """ 读取log数据，并进行清洗
 
@@ -117,8 +148,25 @@ def read_data_lines(data_f, date_selected, time_range):
     cur_voltage_values = []
     torque_values = []
 
+    json_line = True
+
     for line in data_f:
-        data = json.loads(line.strip("\n"))
+        # check if line is json format
+
+        try:
+            data = json.loads(line.strip("\n"))
+            json_line = True
+        except Exception:
+            json_line = False
+            if "n - c" in line:
+                continue
+            # data line maybe like this: 2022-11-07T08:48:23.011000+0800 TRACE:         r - c -69212477 cv -5485 t -1399 T LT3 o 18.71 rf {"10.0.64.121":20,"10.0.64.122":100,"total":58} v 23.63
+        # parse it
+            data = {}
+            data["timestamp"] = find_datetime_in_line(line)
+            data["v"] = find_voltage_in_line(line)
+            data["t"] = find_torque_in_line(line)
+
         # 选取传入时间戳范围内的所有时间
         log_line_time = parse(data["timestamp"])
         log_line_timestamp = log_line_time.timestamp()
@@ -128,7 +176,10 @@ def read_data_lines(data_f, date_selected, time_range):
 
         # 获取相关的电压，扭矩，时间数据
         if (('message' in data.keys()) == False):
-            if data["type"] == "n":
+            if json_line and data["type"] == "n":
+                continue
+
+            if not data['v'] or not data["t"]:
                 continue
 
             timestamp_points.append(log_line_time)
@@ -275,38 +326,63 @@ def create_diagram(input_data, input_args):
     log_datetime = timestamp_points
     date_format = mdates.DateFormatter('%d-%m-%Y/%H:%M:%S')
 
-    rect1 = [0.10, 0.5, 0.80, 0.40]
+    rect1 = [0.10, 0.5, 0.80, 0.45]
+
+    # improve the resolution ratio
+    fig = plt.figure(figsize=(20, 10), dpi=150)
+
     ax1 = plt.axes(rect1)
 
     ax1.xaxis_date()
     ax1.plot(log_datetime, torque_values)
 
-    ax1.set_yticks(range(-1400, 1400, 200))
+    # set y tick major locator
+    ax1.yaxis.set_major_locator(ticker.MultipleLocator(200))
+    # ax1.yaxis.set_major_formatter(FormatStrFormatter('%0.1f'))
+
+    # set y tick minor locator
+    ax1.yaxis.set_minor_locator(ticker.MultipleLocator(10))
+    # ax1.yaxis.set_minor_formatter(FormatStrFormatter('%0.1f'))
+
+    # set y grid
+    ax1.yaxis.grid(True, which='major', linestyle='--')
+
+    # ax1.set_yticks(range(-1400, 1400, 200))
     ax1.xaxis.set_major_formatter(date_format)
     ax1.tick_params(axis='both', labelsize=7)
 
-    ax1.set_ylabel("torque")
+    ax1.set_ylabel("Torque", fontsize=10)
     plt.setp(ax1.get_xticklabels(), rotation=30, ha="right")
 
 
-
     # # 绘制电压时间子图
-    rect2 = [0.10, 0.15, 0.80, 0.15]
+    rect2 = [0.10, 0.15, 0.80, 0.25]
     ax2 = plt.axes(rect2)
 
     ax2.xaxis_date()
     ax2.plot(log_datetime, cur_voltage_values, linewidth=1, c='red')
 
-    ax2.set_yticks(range(0, 80, 10))
+    # set y tick major locator
+    ax2.yaxis.set_major_locator(ticker.MultipleLocator(5))
+
+    # set y tick minor locator
+    ax2.yaxis.set_minor_locator(ticker.MultipleLocator(1))
+
+    # set y grid
+    ax2.yaxis.grid(True, which='major', linestyle='--')
+    ax2.yaxis.grid(True, which='minor', linestyle=':')
+
     ax2.xaxis.set_major_formatter(date_format)
 
-    ax2.tick_params(axis='both', labelsize=7)
     plt.setp(ax2.get_xticklabels(), rotation=30, ha="right")
 
-    ax2.set_ylabel("voltage")
+
+    ax2.set_ylabel("Voltage (V)", fontsize=10)
+
 
     plt.savefig(input_args.output_file)
 
+
     if input_args.plot_show:
         plt.show()
 
